pub struct LoadDatasetTableFromFileRequest {
pub study_id: StudyId,
pub dataset_name: NcName,
pub major: i32,
pub minor: i32,
pub patch: i32,
pub source_path: PathBuf,
pub format: DatasetFileFormat,
pub options: DatasetFileReadOptions,
}Expand description
Request to load one versioned dataset table from a source file.
Fields
study_id: StudyIddataset_name: NcNamemajor: i32minor: i32patch: i32source_path: PathBufformat: DatasetFileFormatoptions: DatasetFileReadOptionsTrait Implementations
Sourceimpl Clone for LoadDatasetTableFromFileRequest
impl Clone for LoadDatasetTableFromFileRequest
Sourcefn clone(&self) -> LoadDatasetTableFromFileRequest
fn clone(&self) -> LoadDatasetTableFromFileRequest
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl PartialEq for LoadDatasetTableFromFileRequest
impl PartialEq for LoadDatasetTableFromFileRequest
Sourcefn eq(&self, other: &LoadDatasetTableFromFileRequest) -> bool
fn eq(&self, other: &LoadDatasetTableFromFileRequest) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Eq for LoadDatasetTableFromFileRequest
impl StructuralPartialEq for LoadDatasetTableFromFileRequest